@@ -421,6 +421,84 @@ class BaseTestRunner(object):
         r3.downgrade('-1', delete_files=False)
         r3.upgrade()
 
+    @pytest.mark.usefixtures("metadata_with_one_edge", "metadata_with_assoc_edge_config")
+    def test_edge_in_db_modified(self, new_test_runner, metadata_with_one_edge, metadata_with_assoc_edge_config):
+        r = testingutils.run_edge_metadata_script(
+            new_test_runner,
+            metadata_with_one_edge,
+            "add edge UserToFollowersEdge",
+            metadata_with_assoc_edge_config
+        )
+        conn = r.get_connection()
+        conn.execute(
+            "UPDATE assoc_edge_config SET edge_table = 'user_to_followers_edge_incorrect'")
+
+        # validate edges fails because edges incorrect
+        with pytest.raises(AssertionError):
+            testingutils.validate_edges_from_metadata(
+                metadata_with_one_edge, r)
+
+        # edge is modified
+        r2 = testingutils.run_edge_metadata_script(
+            new_test_runner,
+            metadata_with_one_edge,
+            "modify edge UserToFollowersEdge",
+            metadata_with_assoc_edge_config,
+            num_files=3,
+            prev_runner=r,
+            num_changes=1
+        )
+
+        # run again, nothing
+        testingutils.run_edge_metadata_script(
+            new_test_runner,
+            metadata_with_one_edge,
+            "",
+            metadata_with_assoc_edge_config,
+            num_files=3,
+            prev_runner=r2,
+            num_changes=0
+        )
+
+    @pytest.mark.usefixtures("metadata_with_inverse_edge", "metadata_with_assoc_edge_config")
+    def test_multiple_edge_table_incorrect_and_modified(self, new_test_runner, metadata_with_inverse_edge, metadata_with_assoc_edge_config):
+        r = testingutils.run_edge_metadata_script(
+            new_test_runner,
+            metadata_with_inverse_edge,
+            "add edges UserToFolloweesEdge, UserToFollowersEdge",
+            metadata_with_assoc_edge_config
+        )
+        conn = r.get_connection()
+        conn.execute(
+            "UPDATE assoc_edge_config SET edge_table = 'user_to_followers_edge_incorrect'")
+
+        # validate edges fails because edges incorrect
+        with pytest.raises(AssertionError):
+            testingutils.validate_edges_from_metadata(
+                metadata_with_inverse_edge, r)
+
+        # edge is modified
+        r2 = testingutils.run_edge_metadata_script(
+            new_test_runner,
+            metadata_with_inverse_edge,
+            "modify edge UserToFollowersEdge\nmodify edge UserToFolloweesEdge",
+            metadata_with_assoc_edge_config,
+            num_files=3,
+            prev_runner=r,
+            num_changes=2
+        )
+
+        # run again, nothing
+        testingutils.run_edge_metadata_script(
+            new_test_runner,
+            metadata_with_inverse_edge,
+            "",
+            metadata_with_assoc_edge_config,
+            num_files=3,
+            prev_runner=r2,
+            num_changes=0
+        )
+
     @pytest.mark.usefixtures("metadata_with_nullable_fields")
     def test_new_table_with_nullable_fields(self, new_test_runner, metadata_with_nullable_fields):
         r = new_test_runner(metadata_with_nullable_fields)
@@ -666,6 +744,7 @@ class BaseTestRunner(object):
         d = Diff(diff, group_by_table=False)
         assert d.list_changes() == [{
             'change': ChangeType.DROP_INDEX,
+            "index": "accounts_first_name_idx",
             'desc': 'drop index accounts_first_name_idx from accounts',
         }, {
             'change': ChangeType.DROP_TABLE,
@@ -676,6 +755,7 @@ class BaseTestRunner(object):
         assert d2.changes() == {
             'accounts': [{
                 'change': ChangeType.DROP_INDEX,
+                "index": "accounts_first_name_idx",
                 'desc': 'drop index accounts_first_name_idx from accounts',
             }, {
                 'change': ChangeType.DROP_TABLE,
@@ -1099,6 +1179,88 @@ class TestPostgresRunner(BaseTestRunner):
         testingutils.run_and_validate_with_standard_metadata_tables(
             r, metadata_with_json, new_table_names=['tbl'])
 
+    @pytest.mark.usefixtures("metadata_with_json")
+    def test_change_jsonb_index_type_explicit(self, new_test_runner, metadata_with_json):
+        r = new_test_runner(metadata_with_json)
+        testingutils.run_and_validate_with_standard_metadata_tables(
+            r, metadata_with_json, new_table_names=['tbl'])
+
+        t = r.get_metadata().tables.get('tbl')
+        indexes = {
+            index.name: index for index in t.indexes}
+
+        index = indexes.get('tbl_nullable_jsonb_idx')
+        assert index.kwargs.get('postgresql_using') == 'btree'
+        index.kwargs['postgresql_using'] = 'gin'
+        r2 = testingutils.recreate_with_new_metadata(
+            r, new_test_runner, metadata_with_json, lambda _: t)
+
+        diff = r2.compute_changes()
+        assert len(diff) == 1
+        assert isinstance(diff[0], alembicops.ModifyTableOps)
+        modify_op = diff[0]
+        assert len(modify_op.ops) == 2
+        # we drop and recreate index
+        assert isinstance(modify_op.ops[0], alembicops.DropIndexOp)
+        assert isinstance(modify_op.ops[1], alembicops.CreateIndexOp)
+
+        r2.run()
+        testingutils.assert_num_files(r2, 2)
+        testingutils.validate_metadata_after_change(r2, r2.get_metadata())
+
+    @pytest.mark.usefixtures("metadata_with_json")
+    def test_change_jsonb_index_type_no_explicit(self, new_test_runner, metadata_with_json):
+        r = new_test_runner(metadata_with_json)
+        testingutils.run_and_validate_with_standard_metadata_tables(
+            r, metadata_with_json, new_table_names=['tbl'])
+
+        t = r.get_metadata().tables.get('tbl')
+        indexes = {
+            index.name: index for index in t.indexes}
+
+        index = indexes.get('tbl_default_jsonb_idx')
+        assert index.kwargs.get('postgresql_using') == False
+        index.kwargs['postgresql_using'] = 'gin'
+        r2 = testingutils.recreate_with_new_metadata(
+            r, new_test_runner, metadata_with_json, lambda _: t)
+
+        diff = r2.compute_changes()
+        assert len(diff) == 1
+        r2.run()
+        assert isinstance(diff[0], alembicops.ModifyTableOps)
+        modify_op = diff[0]
+        assert len(modify_op.ops) == 2
+        # we drop and recreate index
+        assert isinstance(modify_op.ops[0], alembicops.DropIndexOp)
+        assert isinstance(modify_op.ops[1], alembicops.CreateIndexOp)
+
+        r2.run()
+        testingutils.assert_num_files(r2, 2)
+        testingutils.validate_metadata_after_change(r2, r2.get_metadata())
+
+    @pytest.mark.usefixtures("metadata_with_json")
+    def test_change_jsonb_index_type_implicit_explicit_btree(self, new_test_runner, metadata_with_json):
+        r = new_test_runner(metadata_with_json)
+        testingutils.run_and_validate_with_standard_metadata_tables(
+            r, metadata_with_json, new_table_names=['tbl'])
+
+        t = r.get_metadata().tables.get('tbl')
+        indexes = {
+            index.name: index for index in t.indexes}
+
+        index = indexes.get('tbl_default_jsonb_idx')
+        assert index.kwargs.get('postgresql_using') == False
+        index.kwargs['postgresql_using'] = 'btree'
+        r2 = testingutils.recreate_with_new_metadata(
+            r, new_test_runner, metadata_with_json, lambda _: t)
+
+        diff = r2.compute_changes()
+        assert len(diff) == 0
+
+        r2.run()
+        testingutils.assert_num_files(r2, 1)
+        testingutils.validate_metadata_after_change(r2, r2.get_metadata())
+
     @pytest.mark.usefixtures("metadata_with_table")
     def test_full_text_index_added_and_removed(self, new_test_runner, metadata_with_table):
         testingutils.make_changes_and_restore(
